@@ -6,16 +6,9 @@ import logging
 # import numpy as np
 # import seaborn as sn
 from toolkit_w.internal.api_requestor import APIRequestor
-from toolkit_w.internal import vars_global
 from toolkit_w.internal.token_json import UserToken
 from toolkit_w.internal.vars_global import ProblemType, TargetMetric
 from toolkit_w.internal.vars_global import InterpretabilityLevel as Interpt
-from api_clients.hal_client import HalClient
-from api_clients.data_clients import DatasetClient
-from api_clients.reports_client import ReportsClient
-from api_clients.prediction_client import PredictionClient
-from api_clients.ensembles_client import EnsemblesClient
-from api_clients.um_clients import UMClient
 from toolkit_w.resources.auth import authenticate
 import toolkit_w as my_toolkit
 
@@ -68,6 +61,9 @@ class MyWhatify:
         # self.ensembles_client = EnsemblesClient(host=conf_server['ENSEMBLES_HOST'], port=conf_server['ENSEMBLES_PORT'])
         pass
 
+    def authenticate(self, username, password):
+        self.login(email=username,password=password)
+
     def login(self, email, password):
         with allure.step('login with user: ' + str(email)):
             logging.info('login with user: ' + str(email))  # + ' and password: ' + password)
@@ -114,7 +110,9 @@ class MyWhatify:
                 print(e)
         return source_id
 
-    def preparing_data_set(self, source_id, data_set_name, problem_type=ProblemType.CLASSIFICATION, target='class', wait=True):
+    def preparing_data_set(self, source_id, data_set_name, problem_type=ProblemType.CLASSIFICATION, target='class',
+                           retype_columns={'car_id': my_toolkit.vars_global.FeatureType.CATEGORICAL},
+                           sample_id=['car_id'], wait=True):
         with allure.step('Preparing Dataset name: ' + str(data_set_name) + ' source_id= ' + str(source_id) +
                      ' problem_type: ' + str(problem_type) + ' target: ' + str(target) + ' wait: ' + str(wait)):
             dataset_id = -1
@@ -125,10 +123,9 @@ class MyWhatify:
                     datasource_id=source_id,
                     dataset_name=data_set_name,
                     target=target,
-                    # header=True,
                     problem_type=task_type,
-                    sample_id=['car_id'],
-                    retype_columns={'car_id': my_toolkit.vars_global.FeatureType.CATEGORICAL},
+                    sample_id=sample_id,
+                    retype_columns=retype_columns,
                     wait=wait, skip_if_exists=True)['id']
                 print("Dataset {} id is {}".format(data_set_name, dataset_id))
             except Exception as e:
